pub enum Predicate {
Comparison {
left: Box<Expr>,
operator: ComparisonOperator,
right: Box<Expr>,
},
IsNull(Box<Expr>),
And(Box<Predicate>, Box<Predicate>),
Or(Box<Predicate>, Box<Predicate>),
Not(Box<Predicate>),
True,
False,
Placeholder,
}Variants
Comparison
IsNull(Box<Expr>)
And(Box<Predicate>, Box<Predicate>)
Or(Box<Predicate>, Box<Predicate>)
Not(Box<Predicate>)
True
False
Placeholder
Implementations
Sourceimpl Predicate
impl Predicate
Sourcepub fn walk<T, F>(&self, accumulator: T, visitor: &mut F) -> T
pub fn walk<T, F>(&self, accumulator: T, visitor: &mut F) -> T
Recursively walk a predicate tree and accumulate results using a closure
Sourcepub fn assume_null(&self, columns: &[String]) -> Self
pub fn assume_null(&self, columns: &[String]) -> Self
Clones the predicate tree and evaluates comparisons involving missing columns as if they were NULL
Sourcepub fn populate<I, V, E>(self, values: I) -> Result<Predicate, ParseError>
pub fn populate<I, V, E>(self, values: I) -> Result<Predicate, ParseError>
Populate placeholders in the predicate with actual values